import React, { useState, useRef } from "react";
import TodoList from "./TodoList";
import { todo_data } from "./Todo";
import { v4 as uuidv4 } from "uuid";

function App() {
  const [todos, setTodos] = useState<todo_data[]>([]);

  const todoNameRef = useRef<HTMLInputElement>(null);

  const handleAddTodo = (
    e: React.MouseEvent<HTMLButtonElement, MouseEvent>
  ) => {
    // todoNameRef.current.value
    let name = "";

    if (todoNameRef.current == null) {
      return;
    }
    name = todoNameRef.current.value;

    setTodos((prevTodos) => {
      return [...prevTodos, { id: uuidv4(), name: name, completed: false }];
    });

    todoNameRef.current.value = "";
  };

  const toggleCompleted = (todo: todo_data) => {
    const newTodos = [...todos];
    const findTodo = newTodos.find((t) => t.id === todo.id);
    if (findTodo != undefined) {
      findTodo.completed = !findTodo.completed;
    }

    setTodos(newTodos);
  };

  const deleteCompleted = () => {
    const newTodos = todos.filter((todo) => !todo.completed);
    setTodos(newTodos);
  };

  return (
    <div>
      <TodoList todos={todos} toggleCompleted={toggleCompleted} />
      <input type="text" ref={todoNameRef} />
      <button onClick={handleAddTodo}>タスクを追加</button>
      <button onClick={deleteCompleted}>完了したタスクの削除</button>
      <div>残りのタスク:{todos.filter((todo) => !todo.completed).length}</div>
    </div>
  );
}

export default App;
